==> constructorio-client-javascript-2.8.0.tgz: package/lib/constructorio.js <==
"use strict";

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* eslint-disable camelcase */
var ConstructorioID = require('@constructor-io/constructorio-id'); // Modules


var Search = require('./modules/search');

var Browse = require('./modules/browse');

var Autocomplete = require('./modules/autocomplete');

var Recommendations = require('./modules/recommendations');

var Tracker = require('./modules/tracker');

var EventDispatcher = require('./utils/event-dispatcher');

var _require = require('../package.json'),
    packageVersion = _require.version;
/**
 * Class to instantiate the ConstructorIO client.
 */


var ConstructorIO =
/**
 * @param {string} apiKey - Constructor.io API key
 * @param {string} [serviceUrl='https://ac.cnstrc.com'] - API URL endpoint
 * @param {string} [segments] - User segments
 * @param {object} [testCells] - User test cells
 * @param {string} [clientId] - Client ID, defaults to value supplied by 'constructorio-id' module
 * @param {string} [sessionId] - Session id, defaults to value supplied by 'constructorio-id' module
 * @param {string} [userId] - User ID
 * @param {function} [fetch] - If supplied, will be utilized for requests rather than default Fetch API
 * @param {number} [trackingSendDelay] - Amount of time to wait before sending tracking events (in ms)
 * @param {boolean} [sendTrackingEvents] - Indicates if tracking events should be dispatched
 * @param {object} [idOptions] - Options object to be supplied to 'constructorio-id' module
 * @param {object} [eventDispatcher] - Options related to 'EventDispatcher' class
 * @param {boolean} [eventDispatcher.enabled] - Determine if events should be dispatched
 * @param {boolean} [eventDispatcher.waitForBeacon] - Wait for beacon before dispatching events
 * @property {object} [search] - Interface to {@link module:search}
 * @property {object} [browse] - Interface to {@link module:browse}
 * @property {object} [autocomplete] - Interface to {@link module:autocomplete}
 * @property {object} [recommendations] - Interface to {@link module:recommendations}
 * @property {object} [tracker] - Interface to {@link module:tracker}
 * @returns {class}
 */
function ConstructorIO() {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  _classCallCheck(this, ConstructorIO);

  var apiKey = options.apiKey,
      version = options.version,
      serviceUrl = options.serviceUrl,
      segments = options.segments,
      testCells = options.testCells,
      clientId = options.clientId,
      sessionId = options.sessionId,
      userId = options.userId,
      fetch = options.fetch,
      trackingSendDelay = options.trackingSendDelay,
      sendTrackingEvents = options.sendTrackingEvents,
      eventDispatcher = options.eventDispatcher,
      idOptions = options.idOptions;

  if (!apiKey || typeof apiKey !== 'string') {
    throw new Error('API key is a required parameter of type string');
  } // Initialize ID session


  var _ConstructorioID = new ConstructorioID(idOptions || {}),
      session_id = _ConstructorioID.session_id,
      client_id = _ConstructorioID.client_id;

  this.options = {
    apiKey: apiKey,
    version: version || global.CLIENT_VERSION || "ciojs-client-".concat(packageVersion),
    serviceUrl: serviceUrl || 'https://ac.cnstrc.com',
    sessionId: sessionId || session_id,
    clientId: clientId || client_id,
    userId: userId,
    segments: segments,
    testCells: testCells,
    fetch: fetch,
    trackingSendDelay: trackingSendDelay,
    eventDispatcher: eventDispatcher,
    sendTrackingEvents: sendTrackingEvents
  }; // Expose global modules

  this.search = new Search(this.options);
  this.browse = new Browse(this.options);
  this.autocomplete = new Autocomplete(this.options);
  this.recommendations = new Recommendations(this.options);
  this.tracker = new Tracker(this.options); // Dispatch initialization event

  new EventDispatcher(options.eventDispatcher).queue('instantiated', this.options);
};

module.exports = ConstructorIO;

==> constructorio-client-javascript-2.9.0.tgz: package/lib/constructorio.js <==
"use strict";

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* eslint-disable camelcase */
var ConstructorioID = require('@constructor-io/constructorio-id'); // Modules


var Search = require('./modules/search');

var Browse = require('./modules/browse');

var Autocomplete = require('./modules/autocomplete');

var Recommendations = require('./modules/recommendations');

var Tracker = require('./modules/tracker');

var EventDispatcher = require('./utils/event-dispatcher');

var _require = require('../package.json'),
    packageVersion = _require.version;
/**
 * Class to instantiate the ConstructorIO client.
 */


var ConstructorIO =
/**
 * @param {string} apiKey - Constructor.io API key
 * @param {string} [serviceUrl='https://ac.cnstrc.com'] - API URL endpoint
 * @param {string} [segments] - User segments
 * @param {object} [testCells] - User test cells
 * @param {string} [clientId] - Client ID, defaults to value supplied by 'constructorio-id' module
 * @param {string} [sessionId] - Session id, defaults to value supplied by 'constructorio-id' module
 * @param {string} [userId] - User ID
 * @param {function} [fetch] - If supplied, will be utilized for requests rather than default Fetch API
 * @param {number} [trackingSendDelay] - Amount of time to wait before sending tracking events (in ms)
 * @param {boolean} [sendTrackingEvents] - Indicates if tracking events should be dispatched
 * @param {object} [idOptions] - Options object to be supplied to 'constructorio-id' module
 * @param {object} [eventDispatcher] - Options related to 'EventDispatcher' class
 * @param {boolean} [eventDispatcher.enabled] - Determine if events should be dispatched
 * @param {boolean} [eventDispatcher.waitForBeacon] - Wait for beacon before dispatching events
 * @property {object} [search] - Interface to {@link module:search}
 * @property {object} [browse] - Interface to {@link module:browse}
 * @property {object} [autocomplete] - Interface to {@link module:autocomplete}
 * @property {object} [recommendations] - Interface to {@link module:recommendations}
 * @property {object} [tracker] - Interface to {@link module:tracker}
 * @returns {class}
 */
function ConstructorIO() {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  _classCallCheck(this, ConstructorIO);

  var apiKey = options.apiKey,
      version = options.version,
      serviceUrl = options.serviceUrl,
      segments = options.segments,
      testCells = options.testCells,
      clientId = options.clientId,
      sessionId = options.sessionId,
      userId = options.userId,
      fetch = options.fetch,
      trackingSendDelay = options.trackingSendDelay,
      sendTrackingEvents = options.sendTrackingEvents,
      eventDispatcher = options.eventDispatcher,
      idOptions = options.idOptions;

  if (!apiKey || typeof apiKey !== 'string') {
    throw new Error('API key is a required parameter of type string');
  } // Initialize ID session


  var _ConstructorioID = new ConstructorioID(idOptions || {}),
      session_id = _ConstructorioID.session_id,
      client_id = _ConstructorioID.client_id;

  this.options = {
    apiKey: apiKey,
    version: version || global.CLIENT_VERSION || "ciojs-client-".concat(packageVersion),
    serviceUrl: serviceUrl || 'https://ac.cnstrc.com',
    sessionId: sessionId || session_id,
    clientId: clientId || client_id,
    userId: userId,
    segments: segments,
    testCells: testCells,
    fetch: fetch,
    trackingSendDelay: trackingSendDelay,
    sendTrackingEvents: sendTrackingEvents,
    eventDispatcher: eventDispatcher
  }; // Expose global modules

  this.search = new Search(this.options);
  this.browse = new Browse(this.options);
  this.autocomplete = new Autocomplete(this.options);
  this.recommendations = new Recommendations(this.options);
  this.tracker = new Tracker(this.options); // Dispatch initialization event

  new EventDispatcher(options.eventDispatcher).queue('instantiated', this.options);
};

module.exports = ConstructorIO;
